Collider

Struct Collider 

pub struct Collider<T> {
    pub shape: AABB,
    pub offset: Vec2,
    pub state: ColliderState,
    pub category_bits: u32,
    pub mask_bits: u32,
    pub user_tag: T,
    pub owner: BodyHandle,
}
Describes a collider in the shape of Shape. Attached to a body.

Fields

shape: AABB

Currently the only shape is AABB

offset: Vec2

Offset from the body’s position, 0 for centered

state: ColliderState

Whether to treat the body as physical or not

category_bits: u32

Ideally only one bit should be set

mask_bits: u32

Bodies only collide if both of their masks match

user_tag: T

User supplied tag for identification

owner: BodyHandle

Body who owns the collider

Implementations

Source

impl<T> Collider<T>

pub fn new( shape: AABB, offset: Vec2, state: ColliderState, category_bits: u32, mask_bits: u32, user_tag: T, owner: BodyHandle, ) -> Self

pub fn overlaps_aabb( &self, own_position: Vec2, position: Vec2, half_exts: Vec2, ) -> bool

pub fn ray_contact(&self, own_position: Vec2, ray: &Ray) -> Option<Raycast>