pub struct Collider<T> {
pub shape: AABB,
pub offset: Vec2,
pub state: ColliderState,
pub category_bits: u32,
pub mask_bits: u32,
pub user_tag: T,
pub owner: BodyHandle,
}Expand description
Describes a collider in the shape of Shape. Attached to a body.
Fields
shape: AABBCurrently the only shape is AABB
offset: Vec2Offset from the body’s position, 0 for centered
state: ColliderStateWhether to treat the body as physical or not
category_bits: u32Ideally only one bit should be set
mask_bits: u32Bodies only collide if both of their masks match
user_tag: TUser supplied tag for identification
owner: BodyHandleBody who owns the collider
Implementations
Sourceimpl<T> Collider<T>
impl<T> Collider<T>
pub fn new( shape: AABB, offset: Vec2, state: ColliderState, category_bits: u32, mask_bits: u32, user_tag: T, owner: BodyHandle, ) -> Self
pub fn overlaps_aabb( &self, own_position: Vec2, position: Vec2, half_exts: Vec2, ) -> bool
pub fn ray_contact(&self, own_position: Vec2, ray: &Ray) -> Option<Raycast>